#!/usr/bin/python2
#
# Copyright (c) 2013 Intel, Inc.
# Author igor.stoppa@intel.com
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""Base Class - mostly takes care of preventing buffering of output"""

from __future__ import print_function
import sys

VERSION = "0.1.0"

class BaseClass(object):
    """Abstract Base Class providing some common methods."""
    class FlushFile:
        """Class used to avoid buffering of the output messages"""
        def __init__(self, filetoflush):
            self.filetoflush = filetoflush

        def flush(self):
            """flush method"""
            self.filetoflush.flush()

        def write(self, data):
            """write method"""
            self.filetoflush.write(data)
            self.flush()

    def __init__(self):
        if type(self) == BaseClass:
            raise NotImplementedError
        if not isinstance(sys.stdout, self.FlushFile):
            sys.stdout = self.FlushFile(sys.stdout)
        self._verbose = True
