#!/usr/bin/python2
#
# Copyright (c) 2013 Intel, Inc.
# Author igor.stoppa@intel.com
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""Abstract Model of Command Line tool for Tizen robot programs"""

from __future__ import print_function
import sys
import subprocess
from tizentestrobot.baseclass import BaseClass

VERSION = "0.1.0"

class CmdLineTool(BaseClass):
    """Abstract Base Class for wrapping cmdline tools."""
    def __init__(self, command = None, exit_on_error=False):
        if type(self) == CmdLineTool:
            raise NotImplementedError
        BaseClass.__init__(self)
        self._command = command
        self._exit_on_error = exit_on_error
        self._probe_command()

    def _probe_command(self):
        """Tests if a certain shell command is available.
            Can either return error or throw an exception"""
        print("Testing for presence of \"{0}\" " \
              "command ... ".format(self._command), end = "")
        try:
            subprocess.check_output(["which", self._command],
                    stderr = subprocess.STDOUT)
            print("found.")
            return True
        except subprocess.CalledProcessError:
            if self._exit_on_error:
                sys.exit("Error: cannot locate {0} command.".
                         format(self._command))
            return False

    def run(self, parms = []):
        """Executes command with parameters"""
        try:
            command = [self._command] + parms
            return subprocess.check_output(command,
                    stderr = subprocess.STDOUT)
        except subprocess.CalledProcessError, error:
            if self._exit_on_error:
                sys.exit("failed.\n Error running {0}: {1}".\
                     format([self._command] + parms, error))
            else:
                return False

