#!/usr/bin/python2
#
# Copyright (c) 2013 Intel, Inc.
# Author igor.stoppa@intel.com
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""Class to interface with the prekit tool"""

from __future__ import print_function
from tizentestrobot.cmdlinetool import CmdLineTool

VERSION = "0.1.0"

class Prekit(CmdLineTool):
    """Tool for interacting with DUTs in preOS mode"""
    def __init__(self):
        CmdLineTool.__init__(self, "prekit")
        self._devices = []

    def run(self, parms = [], dev_id = None, old = False):
        """Executes prekit with custom parameters"""
        if old:
            parms = ["-o"] + parms
        if dev_id:
            parms = ["-s", "{0}".format(dev_id)] + parms
        return CmdLineTool.run(self, parms)

    def probe_devices(self):
        """Gets list of connected devices in preOS mode"""
        self._devices = []
        devices_list = \
            self.run(["devices"]) + \
            self.run(["devices"], dev_id = None, old = True)
        devices_list = devices_list.decode("utf-8")
        #The output of "prekit [-o] devices" is:
        # 1 line for each device found: "S/N    device    deviceID"
        # 1 trailing "\n"
        devices_list = devices_list.split("\n")
        for i in range(len(devices_list) - 1): #last line is empty
            self._devices.append(devices_list[i].split("\t")[0])
        return self._devices

    def probe_device(self, dev_id):
        """Checks if a given device is reachable in preOS mode"""
        return dev_id in self.probe_devices()
