#!/usr/bin/python2
#
# Copyright (c) 2013 Intel, Inc.
# Author igor.stoppa@intel.com
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""Class to interface with the sdb tool"""

from __future__ import print_function
from tizentestrobot.cmdlinetool import CmdLineTool

class Sdb(CmdLineTool):
    """Tool for interacting with DUTs in Tizen mode"""
    def __init__(self):
        CmdLineTool.__init__(self, "sdb")
        self._devices = []

    def run(self, parms = [], dev_id = None):
        """Executes sdb with custom parameters"""
        if dev_id:
            parms = ["-s", "{0}".format(dev_id)] + parms
        return CmdLineTool.run(self, parms)

    def probe_devices(self):
        """Gets list of connected devices in Tizen mode"""
        self._devices = []
        devices_list = self.run(["devices"])
        devices_list = devices_list.decode("utf-8")
        #The output of "sdb devices" is:
        # 1 line of header "List of devices attached"
        # 1 line for each device found: "S/N	device	deviceID"
        # 1 trailing "\n"
        devices_list = devices_list.split("\n")
        for i in range(1, len(devices_list) - 1): #drop 1st and last line
            self._devices.append(devices_list[i].split("\t")[0])
        return self._devices

    def probe_device(self, dev_id):
        """Checks if a given device is reachable in Tizen mode"""
        return dev_id in self.probe_devices()
