#!/usr/bin/python2
#
# Copyright (c) 2013 Intel, Inc.
# Author igor.stoppa@intel.com
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; version 2 of the License
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the
# Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""Tool for generating config file of connected DUTs and their topology"""

from argparse import ArgumentParser
from lxml import etree
import sys

VERSION = "0.1.0"

class ResultsComparator(object):
    """Compares custom results with reference ones"""
    def __init__(self):
        self._args = None
        self._parser = ArgumentParser()
        self._reference_testcases = None
        self._result_testcases = None

    def _parse_args(self):
        """Takes care of cmd line parameters"""
        self._parser.add_argument("results_filename", action="store",
            nargs="?", default="results.xml",
            help="File with the results from the SW build being tested.")
        self._parser.add_argument("reference_filename", action="store",
            nargs="?", default="reference.xml",
            help="File with the results from the reference SW build.")
        self._args = self._parser.parse_args()
        return self._args

    def _compare_results(self):
        """Compares results and reference and makes decision."""
        reference = etree.parse(self._args.reference_filename)
        reference_testcases = reference.findall("testcase")
        result = etree.parse(self._args.results_filename)
        result_testcases = result.findall("testcase")
        for reference_testcase in reference_testcases:
            reference_attributes = reference_testcase.attrib
            reference_fail = len(reference_testcase.findall("failure"))
            for result_testcase in result_testcases:
                result_attributes = result_testcase.attrib
                if reference_attributes["classname"] == \
                   result_attributes["classname"]:
                    result_fail = len(result_testcase.findall("failure"))
                    if (result_fail > reference_fail):
                        sys.exit(-1)

    def run(self):
        """External access point, main function."""
        self._parse_args()
        print("Results for Reference Image: {0}\n" \
              "Results for Testing Image: {1}".\
              format(self._args.reference_filename,
                     self._args.results_filename))
        self._compare_results()
