/* Arduino USB Keyboard HID
*
* Sends commands to configure
* IVI NDIS HW to boot from USB
*
*/

#define WAITING_BIOS 7000
#define MENU_DELAY    250

#define KEY_F4            0x3d
#define KEY_ARROW_RIGHT   0x4f
#define KEY_ARROW_DOWN    0x51
#define KEY_ENTER         0x28
#define KEY_DEL           0x4c

void setup() 
{
    Serial.begin(9600);
    delay(WAITING_BIOS);
}

// Note: BIOS setup can be entered either by
// F2 or by Del key.
// However the time window for sending the 
// F2/Del key doesn't seem to be very reliable
// Its start can fluctuate by 2-4 s
// so the only way to activate it for sure is
// to send several repetitions of the activation
// key. This means that the key will be sent
// typically also few times after the BIOS has
// already entered setup mode.
// Which rules out F2, because it is used also
// during setup mode.
// The Del key, instead, is ignored and can be 
// safely injected.

// Key sequence for entering BIOS Setup mode
// and selecting as primary boot device the
// one which is currently the second boot device

uint8_t commands[] = {
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_DEL, KEY_DEL, KEY_DEL, KEY_DEL,
                    KEY_ARROW_RIGHT,
                    KEY_ARROW_RIGHT,
                    KEY_ARROW_RIGHT,
                    KEY_ARROW_DOWN,
                    KEY_ARROW_DOWN,
                    KEY_ENTER,
                    KEY_ENTER,
                    KEY_ARROW_DOWN,
                    KEY_ENTER,
                    KEY_F4,
                    KEY_ENTER
                  };

void loop() {
    uint8_t buf[8] = { 0 };	/* Keyboard report buffer */
    int i, wait;
    for (i = 0; i < sizeof(commands); i++) {
        buf[2] = commands[i];
	Serial.write(buf, 8);	// Send keypress
	buf[0] = 0;
	buf[2] = 0;
	Serial.write(buf, 8);	// Release key
        delay(MENU_DELAY);
    }
    while(1); //do not loop: this must be executed only once, at boot
}
